pub async fn status_for<T>() -> Result<ServiceStatusOutput, ZadError>where
T: LifecycleService,Expand description
Collect the status envelope for service T without emitting
anything. Pings only the effective scope.
pub async fn status_for<T>() -> Result<ServiceStatusOutput, ZadError>where
T: LifecycleService,Collect the status envelope for service T without emitting
anything. Pings only the effective scope.