InitArgs

Struct InitArgs 

pub struct InitArgs {
    pub force: bool,
    pub json: bool,
}

Fields

force: bool

Rotate the keychain key, replacing any existing entry. The trust store is reset (every existing trust entry was signed by the old key and would fail verification under the new key); you must re-sign every permissions file you want loaded.

json: bool