pub struct PlaylistsRemoveArgs {
pub playlist: String,
pub items: Vec<String>,
pub dry_run: bool,
pub json: bool,
}Fields
playlist: Stringitems: Vec<String>One or more playlist-item IDs or video IDs. When a video ID is supplied, zad lists the playlist to find the matching item; if the same video appears multiple times, every match is removed.
dry_run: booljson: boolTrait Implementations
Sourceimpl Args for PlaylistsRemoveArgs
impl Args for PlaylistsRemoveArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Debug for PlaylistsRemoveArgs
impl Debug for PlaylistsRemoveArgs
Sourceimpl FromArgMatches for PlaylistsRemoveArgs
impl FromArgMatches for PlaylistsRemoveArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for PlaylistsRemoveArgs
impl RefUnwindSafe for PlaylistsRemoveArgs
impl Send for PlaylistsRemoveArgs
impl Sync for PlaylistsRemoveArgs
impl Unpin for PlaylistsRemoveArgs
impl UnsafeUnpin for PlaylistsRemoveArgs
impl UnwindSafe for PlaylistsRemoveArgs